untie
=====


A Python library implementing TIE (Trace Information Extraction) offering a new approach to extract structural data from geological maps.

Base o the following scientific paper:

    Trace Information Extraction (TIE): A new approach to extract structural information from traces in geological maps (https://doi.org/10.1016/j.jsg.2019.06.007)


![TIE Demo](https://github.com/swisstopo/lg-tie-lib/blob/master/untie_demo.png "TIE demo")


## Installation

**untie** is available on PyPI and Conda

Use pip to install:

```shell
pip install untie
```

Or conda:

```shell
conda install swisstopo::untie
```

## Demo

```shell
 untie_demo 
```


